|madcubapy banner|

.. raw:: html

    <div align="center">
        <a href="https://github.com/dhaasler/madcubapy/actions">
            <img src="https://github.com/dhaasler/madcubapy/actions/workflows/run_tests.yaml/badge.svg" alt="Test Status">
        </a>
        <a href="https://madcubapy.readthedocs.io/en/latest/?badge=latest">
            <img src="https://img.shields.io/readthedocs/madcubapy/latest.svg?logo=read%20the%20docs&logoColor=white&label=Docs" alt="Documentation Status">
        </a>
        <a href="https://pypi.org/project/madcubapy">
            <img src="https://img.shields.io/pypi/v/madcubapy" alt="PyPI Status">
        </a>
    </div>

----

*NOTE: This package is in its first test versions and should not be used in its
current state.*

``madcubapy`` is a package developed to work with MADCUBA products to quickly
access their data in python. 

`MADCUBA <https://cab.inta-csic.es/madcuba/>`_ is a software developed in the
spanish Center of Astrobiology (CSIC-INTA) to analyze astronomical datacubes,
and is built using the ImageJ infrastructure.

Installation
============

Install from PyPI with:

.. code-block:: bash
    
    pip install madcubapy




.. |madcubapy banner| image:: docs/source/_static/logos/readme-banner.svg
    :alt: madcubapy

.. |Test Status| image:: https://github.com/dhaasler/madcubapy/actions/workflows/run_tests.yaml/badge.svg
    :target: https://github.com/dhaasler/madcubapy/actions
    :alt: Test Status

.. |Documentation Status| image:: https://img.shields.io/readthedocs/madcubapy/latest.svg?logo=read%20the%20docs&logoColor=white&label=Docs
    :target: https://madcubapy.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. |PyPI Status| image:: https://img.shields.io/pypi/v/madcubapy
    :target: https://pypi.org/project/madcubapy
    :alt: PyPI Status
